@@ -2,10 +2,11 @@ use strict;
 use warnings;
 package MetaCPAN::Client;
 # ABSTRACT: A comprehensive, DWIM-featured client to the MetaCPAN API
-$MetaCPAN::Client::VERSION = '2.002000';
+$MetaCPAN::Client::VERSION = '2.003000';
 use Moo;
 use Carp;
 use Ref::Util qw< is_arrayref is_hashref >;
+use URI::Escape qw< uri_escape_utf8 >;
 
 use MetaCPAN::Client::Request;
 use MetaCPAN::Client::Author;
@@ -179,7 +180,7 @@ sub autocomplete {
     my $res;
 
     eval {
-        $res = $self->fetch("/search/autocomplete?q=$q");
+        $res = $self->fetch( '/search/autocomplete?q=' . uri_escape_utf8($q) );
         1;
 
     } or do {
@@ -370,7 +371,7 @@ MetaCPAN::Client - A comprehensive, DWIM-featured client to the MetaCPAN API
 
 =head1 VERSION
 
-version 2.002000
+version 2.003000
 
 =head1 SYNOPSIS
 
